@@ -2429,7 +2429,6 @@ func TestConditionEnabled(t *testing.T) {
 		values    map[string]any
 		want      bool
 		wantErr   bool
-		wantPanic bool
 	}{
 		{
 			name:      "enabled",
@@ -2451,6 +2450,17 @@ func TestConditionEnabled(t *testing.T) {
 			},
 			want: false,
 		},
+		{
+			name:      "typo in condition",
+			condition: "fooo.enabled",
+			values: map[string]any{
+				"foo": map[string]any{
+					"enabled": true,
+				},
+			},
+			want:    false,
+			wantErr: true,
+		},
 		{
 			name:      "missing enabled",
 			condition: "foo.enabled",
@@ -2467,13 +2477,15 @@ func TestConditionEnabled(t *testing.T) {
 			values: map[string]any{
 				"foo": nil,
 			},
-			wantPanic: true,
+			want:    false,
+			wantErr: true,
 		},
 		{
 			name:      "foo missing",
 			condition: "foo.enabled",
 			values:    map[string]any{},
-			wantPanic: true,
+			want:      false,
+			wantErr:   true,
 		},
 		{
 			name:      "wrong suffix",
@@ -2502,13 +2514,6 @@ func TestConditionEnabled(t *testing.T) {
 	for i := range tests {
 		tt := tests[i]
 		t.Run(tt.name, func(t *testing.T) {
-			if tt.wantPanic {
-				defer func() {
-					if r := recover(); r == nil {
-						t.Errorf("ConditionEnabled() for %s expected panic", tt.name)
-					}
-				}()
-			}
 			res, err := ConditionEnabled(ReleaseSpec{Condition: tt.condition}, tt.values)
 			if tt.wantErr {
 				if err == nil {
@@ -2590,7 +2595,28 @@ func TestHelmState_Delete(t *testing.T) {
 		namespace      string
 		kubeContext    string
 		defKubeContext string
+		deleteWait     bool
+		deleteTimeout  int
 	}{
+		{
+			name:       "delete wait enabled",
+			deleteWait: true,
+			wantErr:    false,
+			desired:    boolValue(true),
+			installed:  true,
+			purge:      false,
+			deleted:    []exectest.Release{{Name: "releaseA", Flags: []string{"--wait"}}},
+		},
+		{
+			name:          "delete wait with deleteTimeout",
+			deleteWait:    true,
+			deleteTimeout: 800,
+			wantErr:       false,
+			desired:       boolValue(true),
+			installed:     true,
+			purge:         false,
+			deleted:       []exectest.Release{{Name: "releaseA", Flags: []string{"--wait", "--timeout", "800s"}}},
+		},
 		{
 			name:      "desired and installed (purge=false)",
 			wantErr:   false,
@@ -2721,7 +2747,9 @@ func TestHelmState_Delete(t *testing.T) {
 			state := &HelmState{
 				ReleaseSetSpec: ReleaseSetSpec{
 					HelmDefaults: HelmSpec{
-						KubeContext: tt.defKubeContext,
+						KubeContext:   tt.defKubeContext,
+						DeleteWait:    tt.deleteWait,
+						DeleteTimeout: tt.deleteTimeout,
 					},
 					Releases: releases,
 				},
@@ -3156,7 +3184,7 @@ func TestGetOCIQualifiedChartName(t *testing.T) {
 					},
 				},
 			},
-			helmVersion: "3.13.2",
+			helmVersion: "3.13.3",
 			expected: []struct {
 				qualifiedChartName string
 				chartName          string
@@ -3177,7 +3205,7 @@ func TestGetOCIQualifiedChartName(t *testing.T) {
 					},
 				},
 			},
-			helmVersion: "3.13.2",
+			helmVersion: "3.13.3",
 			wantErr:     true,
 		},
 		{
@@ -3212,7 +3240,7 @@ func TestGetOCIQualifiedChartName(t *testing.T) {
 					},
 				},
 			},
-			helmVersion: "3.13.2",
+			helmVersion: "3.13.3",
 			expected: []struct {
 				qualifiedChartName string
 				chartName          string
